``discogui`` discovers GUI elements

Contents:

.. toctree::
    :maxdepth: 2

    readme
    usage
    api
    related
    changes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

